@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -158,7 +158,7 @@ options options[] = {
   { 0, 0, 0, 0, 0 }
 } ;
 int endswith(const char *s, const char *suff) {
-   int off = strlen(s) - strlen(suff) ;
+   int off = (int)(strlen(s) - strlen(suff)) ;
    if (off <= 0)
       return 0 ;
    s += off ;
@@ -487,7 +487,7 @@ void runtestscript(const char *testscript) {
 }
 int main(int argc, char *argv[]) {
    cout << 
-    "This is bgolly " STRINGIFY(VERSION) " Copyright 2011 The Golly Gang." 
+    "This is bgolly " STRINGIFY(VERSION) " Copyright 2012 The Golly Gang." 
                                                             << endl << flush ;
    qlifealgo::doInitializeAlgoInfo(staticAlgoInfo::tick()) ;
    hlifealgo::doInitializeAlgoInfo(staticAlgoInfo::tick()) ;
