@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -201,7 +201,7 @@ const char *bigint::tostring(char sep) const {
    char *r = p ;
    if (neg)
       *r++ = '-' ;
-   for (int i=p-printbuf-1; i>=0; i--) {
+   for (int i=(int)(p-printbuf-1); i>=0; i--) {
       *r++ = printbuf[i] ;
       if (i && sep && (i % sepcount == 0))
          *r++ = sep ;
@@ -377,9 +377,9 @@ void bigint::mul_smallint(int a) {
       return ;
    }
    if (v.i & 1) {
-      c = (v.i >> 1) * a ;
-      if (c / a == (v.i >> 1)) {
-         fromint(c) ;
+      if ((v.i >> 1) <= MAX_SIMPLE / a) {
+         c = (v.i >> 1) * a ;
+         fromint((v.i >> 1) * a) ;
          return ;
       }
       vectorize(v.i >> 1) ;
