@@ -1,7 +1,7 @@
                        /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -533,8 +533,10 @@ void ghashbase::setcurrentstate(void *n) {
 void ghashbase::setMaxMemory(int newmemlimit) {
    if (newmemlimit < 10)
      newmemlimit = 10 ;
-   else if (sizeof(maxmem) <= 4 && newmemlimit > 4000)
+#ifndef GOLLY64BIT
+   else if (newmemlimit > 4000)
      newmemlimit = 4000 ;
+#endif
    g_uintptr_t newlimit = ((g_uintptr_t)newmemlimit) << 20 ;
    if (alloced > newlimit) {
       lifewarning("Sorry, more memory currently used than allowed.") ;
@@ -1149,7 +1151,7 @@ void ghashbase::do_gc(int invalidate) {
       poller->poll() ;
       gc_mark((ghnode *)stack[i], invalidate) ;
    }
-   for (int i=0; i<timeline.framecount; i++)
+   for (i=0; i<timeline.framecount; i++)
       gc_mark((ghnode *)timeline.frames[i], invalidate) ;
    hashpop = 0 ;
    memset(hashtab, 0, sizeof(ghnode *) * hashprime) ;
@@ -1158,7 +1160,7 @@ void ghashbase::do_gc(int invalidate) {
       poller->poll() ;
       for (pp=p+1, i=1; i<1001; i++, pp++) {
          if (marked(pp)) {
-            int h = 0 ;
+            g_uintptr_t h = 0 ;
             if (pp->nw) { /* yes, it's a ghnode */
                h = ghnode_hash(pp->nw, pp->ne, pp->sw, pp->se) % hashprime ;
             } else {
@@ -1177,7 +1179,7 @@ void ghashbase::do_gc(int invalidate) {
    }
    inGC = 0 ;
    if (verbose) {
-     int perc = freed_ghnodes / (totalthings / 100) ;
+     int perc = (int)(freed_ghnodes / (totalthings / 100)) ;
      sprintf(statusline+strlen(statusline), " freed %d percent.", perc) ;
      lifestatus(statusline) ;
    }
@@ -1335,7 +1337,7 @@ ghnode *ghashbase::runpattern() {
 }
 const char *ghashbase::readmacrocell(char *line) {
    int n=0 ;
-   g_uintptr_t i=1, nw, ne, sw, se, indlen=0 ;
+   g_uintptr_t i=1, nw=0, ne=0, sw=0, se=0, indlen=0 ;
    int r, d ;
    ghnode **ind = 0 ;
    root = 0 ;
@@ -1432,8 +1434,7 @@ const char *ghashbase::readmacrocell(char *line) {
 	       g_uintptr_t nodeind = 0 ;
 	       n = sscanf(line+7, "%d %" PRIuPTR, &frameind, &nodeind) ;
 	       if (n != 2 || frameind > MAX_FRAME_COUNT || frameind < 0 ||
-		   nodeind < 0 || nodeind > i ||
-		   timeline.framecount != frameind)
+		   nodeind > i || timeline.framecount != frameind)
 		  return "Bad FRAME line" ;
 	       timeline.frames.push_back(ind[nodeind]) ;
 	       timeline.framecount++ ;
@@ -1463,8 +1464,6 @@ const char *ghashbase::readmacrocell(char *line) {
          if (d < 1)
             return "Oops; bad depth in readmacrocell." ;
          if (d == 1) {
-           if (nw < 0 || ne < 0 || sw < 0 || se < 0)
-              return "Illegal negative cell state values" ;
            if (nw >= (g_uintptr_t)maxCellStates || ne >= (g_uintptr_t)maxCellStates ||
                sw >= (g_uintptr_t)maxCellStates || se >= (g_uintptr_t)maxCellStates)
               return "Cell state values too high for this algorithm." ;
@@ -1473,10 +1472,8 @@ const char *ghashbase::readmacrocell(char *line) {
            depth = d - 1 ;
          } else {
            ind[0] = zeroghnode(d-2) ; /* allow zeros to work right */
-           if (nw < 0 || nw >= i || ind[nw] == 0 ||
-               ne < 0 || ne >= i || ind[ne] == 0 ||
-               sw < 0 || sw >= i || ind[sw] == 0 ||
-               se < 0 || se >= i || ind[se] == 0) {
+           if (nw >= i || ind[nw] == 0 || ne >= i || ind[ne] == 0 ||
+               sw >= i || ind[sw] == 0 || se >= i || ind[se] == 0) {
              return "Node out of range in readmacrocell." ;
            }
            clearstack() ;
