@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -639,8 +639,10 @@ void hlifealgo::setcurrentstate(void *n) {
 void hlifealgo::setMaxMemory(int newmemlimit) {
    if (newmemlimit < 10)
      newmemlimit = 10 ;
-   else if (sizeof(maxmem) <= 4 && newmemlimit > 4000)
+#ifndef GOLLY64BIT
+   else if (newmemlimit > 4000)
      newmemlimit = 4000 ;
+#endif
    g_uintptr_t newlimit = ((g_uintptr_t)newmemlimit) << 20 ;
    if (alloced > newlimit) {
       lifewarning("Sorry, more memory currently used than allowed.") ;
@@ -1282,7 +1284,7 @@ void hlifealgo::do_gc(int invalidate) {
       poller->poll() ;
       gc_mark(stack[i], invalidate) ;
    }
-   for (int i=0; i<timeline.framecount; i++)
+   for (i=0; i<timeline.framecount; i++)
       gc_mark((node *)timeline.frames[i], invalidate) ;
    hashpop = 0 ;
    memset(hashtab, 0, sizeof(node *) * hashprime) ;
@@ -1291,7 +1293,7 @@ void hlifealgo::do_gc(int invalidate) {
       poller->poll() ;
       for (pp=p+1, i=1; i<1001; i++, pp++) {
          if (marked(pp)) {
-            int h = 0 ;
+            g_uintptr_t h = 0 ;
             if (pp->nw) { /* yes, it's a node */
                h = node_hash(pp->nw, pp->ne, pp->sw, pp->se) % hashprime ;
             } else {
@@ -1312,7 +1314,7 @@ void hlifealgo::do_gc(int invalidate) {
    }
    inGC = 0 ;
    if (verbose) {
-     int perc = freed_nodes / (totalthings / 100) ;
+     int perc = (int)(freed_nodes / (totalthings / 100)) ;
      sprintf(statusline+strlen(statusline), " freed %d percent (%d).",
                                                    perc, (int)freed_nodes) ;
      lifestatus(statusline) ;
@@ -1471,7 +1473,7 @@ node *hlifealgo::runpattern() {
 }
 const char *hlifealgo::readmacrocell(char *line) {
    int n=0 ;
-   g_uintptr_t i=1, nw, ne, sw, se, indlen=0 ;
+   g_uintptr_t i=1, nw=0, ne=0, sw=0, se=0, indlen=0 ;
    int r, d ;
    node **ind = 0 ;
    root = 0 ;
@@ -1600,8 +1602,7 @@ default:       return "Illegal character in readmacrocell." ;
 	       g_uintptr_t nodeind = 0 ;
 	       n = sscanf(line+7, "%d %" PRIuPTR, &frameind, &nodeind) ;
 	       if (n != 2 || frameind > MAX_FRAME_COUNT || frameind < 0 ||
-		   nodeind < 0 || nodeind > i ||
-		   timeline.framecount != frameind)
+		   nodeind > i || timeline.framecount != frameind)
 		  return "Bad FRAME line" ;
 	       timeline.frames.push_back(ind[nodeind]) ;
 	       timeline.framecount++ ;
@@ -1631,10 +1632,8 @@ default:       return "Illegal character in readmacrocell." ;
          if (d < 4)
             return "Oops; bad depth in readmacrocell." ;
          ind[0] = zeronode(d-2) ; /* allow zeros to work right */
-         if (nw < 0 || nw >= i || ind[nw] == 0 ||
-             ne < 0 || ne >= i || ind[ne] == 0 ||
-             sw < 0 || sw >= i || ind[sw] == 0 ||
-             se < 0 || se >= i || ind[se] == 0) {
+         if (nw >= i || ind[nw] == 0 || ne >= i || ind[ne] == 0 ||
+             sw >= i || ind[sw] == 0 || se >= i || ind[se] == 0) {
             return "Node out of range in readmacrocell." ;
          }
          clearstack() ;
@@ -1873,7 +1872,7 @@ const char *hlifealgo::writeNativeFormat(std::ostream &os, char *comments) {
      for (int i=0; i<timeline.framecount; i++) {
        node *frame = (node*)timeline.frames[i] ;
        writecell_2p2(os, frame, depths[i]) ;
-       os << "#FRAME " << i << ' ' << (g_uintptr_t)frame->next ;
+       os << "#FRAME " << i << ' ' << (g_uintptr_t)frame->next << '\n' ;
      }
    }
    writecell_2p2(os, root, depth) ;
