@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -173,7 +173,7 @@ public:
    virtual int isEmpty() ;
    virtual int hyperCapable() { return 1 ; }
    virtual void setMaxMemory(int m) ;
-   virtual int getMaxMemory() { return maxmem >> 20 ; }
+   virtual int getMaxMemory() { return (int)(maxmem >> 20) ; }
    virtual const char *setrule(const char *s) ;
    virtual const char *getrule() { return hliferules.getrule() ; }
    virtual void step() ;
