@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -88,10 +88,10 @@ void draw4x4_2(unsigned short bits1, unsigned short bits2, int llx, int lly) {
 
 void draw4x4_4(unsigned short bits1, unsigned short bits2, int llx, int lly) {
    unsigned char *p = bigbuf + ((bmsize-1+lly) << (logbmsize-3)) + ((-llx) >> 3) ;
-   p[0] = ((bits1 << 4) & 0xf0) + (bits2 & 0xf) ;
-   p[-byteoff] = (bits1 & 0xf0) + ((bits2 >> 4) & 0xf) ;
-   p[-2*byteoff] = ((bits1 >> 4) & 0xf0) + ((bits2 >> 8) & 0xf) ;
-   p[-3*byteoff] = ((bits1 >> 8) & 0xf0) + ((bits2 >> 12) & 0xf) ;
+   p[0] = (unsigned char)(((bits1 << 4) & 0xf0) + (bits2 & 0xf)) ;
+   p[-byteoff] = (unsigned char)((bits1 & 0xf0) + ((bits2 >> 4) & 0xf)) ;
+   p[-2*byteoff] = (unsigned char)(((bits1 >> 4) & 0xf0) + ((bits2 >> 8) & 0xf)) ;
+   p[-3*byteoff] = (unsigned char)(((bits1 >> 8) & 0xf0) + ((bits2 >> 12) & 0xf)) ;
 }
 
 void hlifealgo::clearrect(int minx, int miny, int w, int h) {
@@ -237,7 +237,7 @@ void hlifealgo::fill_ll(int d) {
 static void init_compress4x4() {
    int i;
    for (i=0; i<8; i++)
-      compress4x4[1<<i] = (unsigned char)(0x11 << (i >> 1)) ;
+      compress4x4[((size_t)1)<<i] = (unsigned char)(0x11 << (i >> 1)) ;
    for (i=0; i<256; i++)
       if (i & (i-1))
          compress4x4[i] = compress4x4[i & (i-1)] | compress4x4[i & -i] ;
