@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -82,7 +82,7 @@ const char* jvnalgo::getrule() {
    sprintf(canonrule, "%s", RULE_STRINGS[current_rule]);
    if (gridwd > 0 || gridht > 0) {
       // setgridsize() was successfully called above, so append suffix
-      int len = strlen(canonrule);
+      int len = (int)strlen(canonrule);
       const char* bounds = canonicalsuffix();
       int i = 0;
       while (bounds[i]) canonrule[len++] = bounds[i++];
@@ -236,7 +236,7 @@ state jvnalgo::slowcalc(state, state n, state, state w, state c, state e,
 		 c = 0 ;
 	      else if (current_rule == Nobili32 && (mbits & BIT_CROSS) == BIT_CROSS) {
 		 if (mbits & BIT_OEXC)
-		    c = (mbits & BIT_OEXC) + CONF + 0x80 ;
+		    c = (state)((mbits & BIT_OEXC) + CONF + 0x80) ;
 		 else
 		    c = CONF ;
 	      } else {
