@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -36,7 +36,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "platform.h"
 #include <cstdio>
 // moving the include vector *before* platform.h breaks compilation
+#ifdef _MSC_VER
+   #pragma warning(disable:4702)   // disable "unreachable code" warnings from MSVC
+#endif
 #include <vector>
+#ifdef _MSC_VER
+   #pragma warning(default:4702)   // enable "unreachable code" warnings
+#endif
 using std::vector;
 #include <iostream>
 
@@ -90,7 +96,7 @@ public:
    virtual void lowerRightPixel(bigint &x, bigint &y, int mag) = 0 ;
    virtual const char *writeNativeFormat(std::ostream &os, char *comments) = 0 ;
    void setpoll(lifepoll *pollerarg) { poller = pollerarg ; }
-   virtual const char *readmacrocell(char *) { return "cannot read hash" ; }
+   virtual const char *readmacrocell(char *) { return "Cannot read macrocell format." ; }
    
    // Verbosity crosses algorithms.  We need to embed this sort of option
    // into some global shared thing or something rather than use static.
