@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -39,15 +39,22 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *   need to make some changes here.
  */
 #include <limits.h>
-#if defined(__LP64__) || defined(__amd64__)
+#if defined(_WIN64)
+   #define PRIuPTR "I64u"
+   typedef uintptr_t g_uintptr_t ;
+   #define G_MAX SIZE_MAX
+   #define GOLLY64BIT (1)
+#elif defined(__LP64__) || defined(__amd64__)
    #define __STDC_FORMAT_MACROS
    #define __STDC_LIMIT_MACROS
    #include <inttypes.h>
    #include <stdint.h>
    typedef uintptr_t g_uintptr_t ;
    #define G_MAX SIZE_MAX
+   #define GOLLY64BIT (1)
 #else
    #define PRIuPTR "u"
    typedef unsigned int g_uintptr_t ;
    #define G_MAX UINT_MAX
+   #undef GOLLY64BIT
 #endif
