@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -278,9 +278,11 @@ void qlifealgo::setMaxMemory(int newmemlimit) {
       return;
    }
    if (newmemlimit < 10)
-     newmemlimit = 10 ;
-   else if (sizeof(maxmemory) <= 4 && newmemlimit > 4000)
-     newmemlimit = 4000 ;
+      newmemlimit = 10 ;
+#ifndef GOLLY64BIT
+   else if (newmemlimit > 4000)
+      newmemlimit = 4000 ;
+#endif
    g_uintptr_t newlimit = ((g_uintptr_t)newmemlimit) << 20 ;
    if (usedmemory > newlimit) {
       lifewarning("Sorry, more memory currently used than allowed.") ;
