@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -73,7 +73,7 @@ int mgetchar() {
          #endif
       #else
          bytesread = fread(filebuff, 1, BUFFSIZE, pattfile);
-         filepos = ftell(filebuff);
+         filepos = ftell(pattfile);
       #endif
       buffpos = 0;
       lifeabortprogress(filepos / filesize, "");
@@ -617,10 +617,12 @@ const char *loadpattern(lifealgo &imp) {
          // try "Life" in case given algo is RuleTable/RuleTree and a
          // Life.table/tree file exists (nicer for loading lexicon patterns)
          err = imp.setrule("Life");
+         if (err) {
+            // if given algo doesn't support B3/S23 or Life then the only sensible
+            // choice left is to use the algo's default rule
+            err = imp.setrule( imp.DefaultRule() ) ;
+         }
       }
-      // if given algo doesn't support B3/S23 or Life then the only sensible
-      // choice left is to use the algo's default rule
-      if (err) imp.setrule( imp.DefaultRule() ) ;
    }
 
    if (getedges)
@@ -815,7 +817,7 @@ const char *readcomments(const char *filename, char **commptr)
          if (line[0] == '#' &&
                !(line[1] == 'P' && line[2] == ' ') &&
                !(line[1] == 'N' && line[2] == 0)) {
-            int linelen = strlen(line);
+            int linelen = (int)strlen(line);
             if (commlen + linelen + 1 > maxcommlen) break;
             strncpy(cptr + commlen, line, linelen);
             commlen += linelen;
@@ -832,7 +834,7 @@ const char *readcomments(const char *filename, char **commptr)
          if (line[0] != '#') break;
          if (line[1] == 'L' && line[2] == ' ') break;
          if (line[1] == 'D' && (line[2] == ' ' || line[2] == 0)) {
-            int linelen = strlen(line);
+            int linelen = (int)strlen(line);
             if (commlen + linelen + 1 > maxcommlen) break;
             strncpy(cptr + commlen, line, linelen);
             commlen += linelen;
@@ -844,7 +846,7 @@ const char *readcomments(const char *filename, char **commptr)
    } else if (line[0] == '#' || line[0] == 'x') {
       // extract comment lines from RLE file
       while (line[0] == '#') {
-         int linelen = strlen(line);
+         int linelen = (int)strlen(line);
          if (commlen + linelen + 1 > maxcommlen) break;
          strncpy(cptr + commlen, line, linelen);
          commlen += linelen;
@@ -861,7 +863,7 @@ const char *readcomments(const char *filename, char **commptr)
          }
          if (foundexcl) {
             while (getline(line, LINESIZE)) {
-               int linelen = strlen(line);
+               int linelen = (int)strlen(line);
                if (commlen + linelen + 1 > maxcommlen) break;
                strncpy(cptr + commlen, line, linelen);
                commlen += linelen;
@@ -874,7 +876,7 @@ const char *readcomments(const char *filename, char **commptr)
    } else if (line[0] == '!') {
       // extract "!..." lines from dblife file
       while (line[0] == '!') {
-         int linelen = strlen(line);
+         int linelen = (int)strlen(line);
          if (commlen + linelen + 1 > maxcommlen) break;
          strncpy(cptr + commlen, line, linelen);
          commlen += linelen;
@@ -888,7 +890,7 @@ const char *readcomments(const char *filename, char **commptr)
       while (getline(line, LINESIZE)) {
          if (line[0] != '#') break;
          if (line[1] == 'C') {
-            int linelen = strlen(line);
+            int linelen = (int)strlen(line);
             if (commlen + linelen + 1 > maxcommlen) break;
             strncpy(cptr + commlen, line, linelen);
             commlen += linelen;
