@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -58,14 +58,15 @@ const char* ruletable_algo::setrule(const char* s)
    if (colonptr) 
       rule_name.assign(s,colonptr);
 
-   string ret = LoadRuleTable(rule_name.c_str());
+   static string ret;  // NOTE: don't initialize this statically!
+   ret = LoadRuleTable(rule_name.c_str());
    if(!ret.empty())
    {
       // if the file exists and we've got an error then it must be a file format issue
       if(!starts_with(ret,"Failed to open file: "))
          lifewarning(ret.c_str());
 
-      return "error";
+      return ret.c_str();
    }
    
    // check for rule suffix like ":T200,100" to specify a bounded universe
@@ -177,7 +178,7 @@ static FILE *OpenTableFile(string &rule, const char *dir, string &path)
 {
    // look for rule.table in given dir and set path
    path = dir;
-   int istart = path.size();
+   int istart = (int)path.size();
    path += rule + ".table";
    // change "dangerous" characters to underscores
    for (unsigned int i=istart; i<path.size(); i++)
@@ -345,14 +346,14 @@ string ruletable_algo::LoadRuleTable(string rule)
             }
             else
             {
-               unsigned int s;
-               if(sscanf(tokens[i].c_str(),"%d",&s)!=1)
+               unsigned int s=0;
+               if(sscanf(tokens[i].c_str(),"%u",&s)!=1)
                {
                   ostringstream oss;
                   oss << "Error reading " << full_filename << " on line " << lineno << ": " << line;
                   return oss.str();
                }
-               if(s<0 || s>=n_states)
+               if( s>=n_states)
                {
                   ostringstream oss;
                   oss << "Error reading " << full_filename << " on line " << lineno << ": " << line << " - state value out of range";
@@ -420,7 +421,7 @@ string ruletable_algo::LoadRuleTable(string rule)
             for(map< string, vector<state> >::const_iterator var_it=variables.begin();var_it!=variables.end();var_it++)
                if(count(tokens.begin(),tokens.begin()+n_inputs+1,var_it->first)>1)
                   bound_variables.push_back(var_it->first);
-            unsigned int n_bound_variables = bound_variables.size();
+            unsigned int n_bound_variables = (unsigned int)bound_variables.size();
             // second pass: iterate through the possible states for the bound variables, adding a transition for each combination
             vector< vector<state> > inputs(n_inputs);
             state output;
@@ -438,20 +439,20 @@ string ruletable_algo::LoadRuleTable(string rule)
                      inputs[i] = variables[tokens[i]]; // this input is an unbound variable
                   else 
                   {
-                     unsigned int s;
-                     if(sscanf(tokens[i].c_str(),"%d",&s)!=1) // this input is a state
+                     unsigned int s=0;
+                     if(sscanf(tokens[i].c_str(),"%u",&s)!=1) // this input is a state
                      {
                         ostringstream oss;
                         oss << "Error reading " << full_filename << " on line " << lineno << ": " << line;
                         return oss.str();
                      }
-                     if(s<0 || s>=n_states)
+                     if(s>=n_states)
                      {
                         ostringstream oss;
                         oss << "Error reading " << full_filename << " on line " << lineno << ": " << line << " - state out of range";
                         return oss.str();
                      }
-                     inputs[i] = vector<state>(1,s);
+                     inputs[i] = vector<state>(1,(state)s);
                   }
                }
                // collect the output
@@ -467,20 +468,20 @@ string ruletable_algo::LoadRuleTable(string rule)
                      // single-state variables are permitted as the output
                      s = variables[tokens[n_inputs]][0];
                   }
-                  else if(sscanf(tokens[n_inputs].c_str(),"%d",&s)!=1) // if not a bound variable, output must be a state
+                  else if(sscanf(tokens[n_inputs].c_str(),"%u",&s)!=1) // if not a bound variable, output must be a state
                   {
                      ostringstream oss;
                      oss << "Error reading " << full_filename << " on line " << lineno << ": " << line
                         << " - output must be state, single-state variable or bound variable";
                      return oss.str();
                   }
-                  if(s<0 || s>=n_states)
+                  if(s>=n_states)
                   {
                      ostringstream oss;
                      oss << "Error reading " << full_filename << " on line " << lineno << ": " << line << " - state out of range";
                      return oss.str();
                   }
-                  output = s;
+                  output = (state)s;
                }
                transition_table.push_back(make_pair(inputs,output));
                // move on to the next value of bound variables
@@ -619,11 +620,11 @@ void ruletable_algo::PackTransitions(const string& symmetries, int n_inputs,
 void ruletable_algo::PackTransition(const vector< vector<state> > & inputs,
                                     state output)
 {
-    int n_inputs = inputs.size();
-    const unsigned int n_bits = sizeof(TBits)*8;
+    int n_inputs = (int)inputs.size();
+    const unsigned int n_bits = (unsigned int)(sizeof(TBits)*8);
     
     this->output.push_back(output);
-    int iRule = this->output.size()-1;
+    int iRule = (int)(this->output.size()-1);
     int iBit = iRule % n_bits;
     unsigned int iRuleC = (iRule-iBit)/n_bits; // the compressed index of the rule
     
