@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -128,8 +128,9 @@ void linereader::setcloseonfree() {
 }
 int linereader::close() {
    if (fp) {
-      return fclose(fp) ;
+      int r = fclose(fp) ;
       fp = 0 ;
+      return r ;
    }
    return 0 ;
 }
