@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -72,7 +72,7 @@ void AddRun(std::ostream &f,
 
    if ( run > 1 ) {
       sprintf(numstr, "%u", run);
-      numlen = strlen(numstr);
+      numlen = (int)strlen(numstr);
    } else {
       numlen = 0;                      // no run count shown if 1
    }
@@ -272,11 +272,11 @@ public:
       return res == Z_OK ? this : NULL;
    }
 
-   bool is_open() const { return file; }
+   bool is_open() const { return file!=NULL; }
 
    std::streamsize xsputn(const char_type *s, std::streamsize n)
    {
-      return gzwrite(file, s, n);
+      return gzwrite(file, s, (unsigned int)n);
    }
 
    int sync()
