@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -471,9 +471,27 @@ void MainFrame::DisplayPattern()
    // exist it only updates the current tile if possible; ie. it's not a clone
    // and tile views aren't synchronized
    
-   if (!IsIconized()) {
-      if (tilelayers && numlayers > 1 && !syncviews && currlayer->cloneid == 0) {
-         // only update the current tile
+   if (tilelayers && numlayers > 1 && !syncviews && currlayer->cloneid == 0) {
+      // only update the current tile
+      viewptr->Refresh(false);
+      #ifdef __WXMAC__
+         if (!showstatus) viewptr->Update();
+         // else let statusptr->Update() update viewport
+      #else
+         viewptr->Update();
+      #endif
+   } else {
+      // update main viewport window, possibly including all tile windows
+      // (tile windows are children of bigview)
+      if (numlayers > 1 && (stacklayers || tilelayers)) {
+         bigview->Refresh(false);
+         #ifdef __WXMAC__
+            if (!showstatus) bigview->Update();
+            // else let statusptr->Update() update viewport
+         #else
+            bigview->Update();
+         #endif
+      } else {
          viewptr->Refresh(false);
          #ifdef __WXMAC__
             if (!showstatus) viewptr->Update();
@@ -481,33 +499,14 @@ void MainFrame::DisplayPattern()
          #else
             viewptr->Update();
          #endif
-      } else {
-         // update main viewport window, possibly including all tile windows
-         // (tile windows are children of bigview)
-         if (numlayers > 1 && (stacklayers || tilelayers)) {
-            bigview->Refresh(false);
-            #ifdef __WXMAC__
-               if (!showstatus) bigview->Update();
-               // else let statusptr->Update() update viewport
-            #else
-               bigview->Update();
-            #endif
-         } else {
-            viewptr->Refresh(false);
-            #ifdef __WXMAC__
-               if (!showstatus) viewptr->Update();
-               // else let statusptr->Update() update viewport
-            #else
-               viewptr->Update();
-            #endif
-         }
-      }
-      if (showstatus) {
-         statusptr->CheckMouseLocation(IsActive());
-         statusptr->Refresh(false);
-         statusptr->Update();
       }
    }
+   
+   if (showstatus) {
+      statusptr->CheckMouseLocation(IsActive());
+      statusptr->Refresh(false);
+      statusptr->Update();
+   }
 }
 
 // -----------------------------------------------------------------------------
@@ -1145,7 +1144,8 @@ bool MainFrame::StepPattern()
    }
    
    if (currlayer->autofit) viewptr->FitInView(0);
-   DisplayPattern();
+   
+   if (!IsIconized()) DisplayPattern();
    
    /*!!! enable this code if we ever implement isPeriodic()
    if (autostop) {
