@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -410,7 +410,7 @@ void EditBar::DrawAllStates(wxDC& dc, int wd)
       
       // draw state value
       strbuf.Printf(_("%d"), i);
-      x = h_col2 + (i - firststate) * COLWD + (COLWD - strbuf.length() * digitwd) / 2;
+      x = (int)(h_col2 + (i - firststate) * COLWD + (COLWD - strbuf.length() * digitwd) / 2);
       DisplayText(dc, strbuf, x, BASELINE1);
       
       // draw color box
@@ -603,7 +603,6 @@ void EditBar::OnMouseDown(wxMouseEvent& event)
           currlayer->drawingstate != box) {
          currlayer->drawingstate = box;
          Refresh(false);
-         Update();
          UpdateScrollBar();
          return;
       }
@@ -905,7 +904,6 @@ void UpdateEditBar(bool active)
       editbarptr->EnableButton(ALLSTATES_BUTT,  active);
       
       editbarptr->Refresh(false);
-      editbarptr->Update();
       
       // drawing state might have changed
       editbarptr->UpdateScrollBar();
@@ -994,7 +992,6 @@ void CycleDrawingState(bool higher)
    
    if (showedit) {
       editbarptr->Refresh(false);
-      editbarptr->Update();
       editbarptr->UpdateScrollBar();
    }
 }
