@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -364,6 +364,11 @@ void MainFrame::LoadPattern(const wxString& path, const wxString& newtitle,
    } else {
       const char* err = readpattern(FILEPATH, *currlayer->algo);
       if (err) {
+         wxString bigerr = _("File could not be loaded by any algorithm.");
+         wxString algoname = wxString(GetAlgoName(currlayer->algtype), wxConvLocal);
+         bigerr += wxString::Format(_("\n\nError from %s:\n"), algoname.c_str());
+         bigerr += wxString(err, wxConvLocal);
+      
          // cycle thru all other algos until readpattern succeeds
          for (int i = 0; i < NumAlgos(); i++) {
             if (i != oldalgo) {
@@ -372,7 +377,13 @@ void MainFrame::LoadPattern(const wxString& path, const wxString& newtitle,
                currlayer->algo = CreateNewUniverse(currlayer->algtype);
                // readpattern will call setrule
                err = readpattern(FILEPATH, *currlayer->algo);
-               if (!err) break;
+               if (err) {
+                   algoname = wxString(GetAlgoName(currlayer->algtype), wxConvLocal);
+                   bigerr += wxString::Format(_("\n\nError from %s:\n"), algoname.c_str());
+                   bigerr += wxString(err, wxConvLocal);
+               } else {
+                  break;
+               }
             }
          }
          viewptr->nopattupdate = false;
@@ -382,10 +393,7 @@ void MainFrame::LoadPattern(const wxString& path, const wxString& newtitle,
             delete currlayer->algo;
             currlayer->algo = CreateNewUniverse(currlayer->algtype);
             RestoreRule(oldrule);
-            // Warning( wxString(err,wxConvLocal) );
-            // current error and original error are not necessarily meaningful
-            // so report a more generic error
-            Warning(_("File could not be loaded by any algorithm\n(probably due to an unknown rule)."));
+            Warning(bigerr);
          }
       }
       viewptr->nopattupdate = false;
@@ -594,7 +602,7 @@ void MainFrame::OpenZipFile(const wxString& zippath)
          // indent depending on # of separators in name
          unsigned int sepcount = 0;
          unsigned int i = 0;
-         unsigned int len = name.length();
+         unsigned int len = (unsigned int)name.length();
          while (i < len) {
             if (name[i] == wxFILE_SEP_PATH) sepcount++;
             i++;
