@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -753,12 +753,12 @@ void ClickLexiconPattern(const wxHtmlCell* htmlcell)
                   } else {
                      lexpattern += celltext;
                      // append eol char(s)
-                     #if defined(__WXMAC__)
-                        lexpattern += '\r';
-                     #elif defined(__WXMSW__)
+                     #ifdef __WXMSW__
+                        // use DOS line ending (CR+LF) on Windows
                         lexpattern += '\r';
                         lexpattern += '\n';
-                     #else // assume Linux
+                     #else
+                        // use LF on Linux or Mac
                         lexpattern += '\n';
                      #endif
                   }
@@ -854,19 +854,8 @@ void HtmlView::OnLinkClicked(const wxHtmlLinkInfo& link)
    wxString url = link.GetHref();
    if ( url.StartsWith(wxT("http:")) || url.StartsWith(wxT("mailto:")) ) {
       // pass http/mailto URL to user's preferred browser/emailer
-      #if defined(__WXMAC__)
-         // wxLaunchDefaultBrowser doesn't work on Mac with IE (get msg in console.log)
-         // but it's easier just to use the Mac OS X open command
-         if ( wxExecute(wxT("open ") + url, wxEXEC_ASYNC) == -1 )
-            Warning(_("Could not open URL!"));
-      #elif defined(__WXGTK__)
-         // wxLaunchDefaultBrowser is not reliable on Linux/GTK so we call gnome-open
-         if ( wxExecute(wxT("gnome-open ") + url, wxEXEC_ASYNC) == -1 )
-            Warning(_("Could not open URL!"));
-      #else
-         if ( !wxLaunchDefaultBrowser(url) )
-            Warning(_("Could not launch browser!"));
-      #endif
+      if ( !wxLaunchDefaultBrowser(url) )
+         Warning(_("Could not open URL in browser!"));
 
    } else if ( url.StartsWith(wxT("get:")) ) {
       if (mainptr->generating) {
