@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -702,7 +702,6 @@ void UpdateLayerBar(bool active)
 
       // no need to redraw entire bar here if it only contains buttons
       // layerbarptr->Refresh(false);
-      // layerbarptr->Update();
    }
 }
 
@@ -719,7 +718,6 @@ void UpdateLayerButton(int index, const wxString& name)
 void RedrawLayerBar()
 {
    layerbarptr->Refresh(false);
-   layerbarptr->Update();
 }
 
 // -----------------------------------------------------------------------------
@@ -2749,7 +2747,6 @@ void ColorDialog::UpdateButtonColor(int id, wxColor* rgb)
       dc.SelectObject(wxNullBitmap);
       bb->SetBitmapLabel(bitmap);
       bb->Refresh();
-      bb->Update();
    }
 }
 
