@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -294,6 +294,7 @@ extern wxBrush* borderbrush;     // brush for filling grid border
 extern wxPen* pastepen;          // pen for drawing paste rect
 
 void SetBrushesAndPens();        // update colors in above brushes and pens
+void FreeDefaultColors();        // deallocate memory allocated by CreateDefaultColors()
 
 // Various constants:
 
@@ -349,6 +350,9 @@ extern wxCursor* curs_hand;      // for moving view by dragging
 extern wxCursor* curs_zoomin;    // for zooming in to a clicked cell
 extern wxCursor* curs_zoomout;   // for zooming out from a clicked cell
 
+void FreeCursors();
+// deallocate memory allocated by CreateCursors()
+
 const char* CursorToString(wxCursor* curs);
 // convert given cursor to corresponding string in Cursor Mode submenu
 
