@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -177,18 +177,8 @@ void AlgoHelp::OnLinkClicked(const wxHtmlLinkInfo& link)
    wxString url = link.GetHref();
    if ( url.StartsWith(wxT("http:")) || url.StartsWith(wxT("mailto:")) ) {
       // pass http/mailto URL to user's preferred browser/emailer
-      #ifdef __WXMAC__
-         // best to use the Mac OS X open command
-         if ( wxExecute(wxT("open ") + url, wxEXEC_ASYNC) == -1 )
-            Warning(_("Could not open URL!"));
-      #elif defined(__WXGTK__)
-         // wxLaunchDefaultBrowser is not reliable on Linux/GTK so we call gnome-open
-         if ( wxExecute(wxT("gnome-open ") + url, wxEXEC_ASYNC) == -1 )
-            Warning(_("Could not open URL!"));
-      #else
-         if ( !wxLaunchDefaultBrowser(url) )
-            Warning(_("Could not launch browser!"));
-      #endif
+      if ( !wxLaunchDefaultBrowser(url) )
+         Warning(_("Could not open URL in browser!"));
 
    } else if ( url.StartsWith(wxT("rule:")) ) {
       // copy clicked rule into rule box
@@ -736,7 +726,7 @@ void RuleDialog::UpdateName()
          // extract rule after '|'
          wxString thisrule = namedrules[i].AfterFirst('|');
          if ( newrule.IsSameAs(thisrule,false) ) {
-            newindex = i;
+            newindex = (int)i;
             break;
          }
       }
