@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -346,12 +346,12 @@ const char* GSF_setpos(char* x, char* y)
 {
    // disallow alphabetic chars in x,y
    int i;
-   int xlen = strlen(x);
+   int xlen = (int)strlen(x);
    for (i = 0; i < xlen; i++)
       if ( (x[i] >= 'a' && x[i] <= 'z') || (x[i] >= 'A' && x[i] <= 'Z') )
          return "Illegal character in x value.";
 
-   int ylen = strlen(y);
+   int ylen = (int)strlen(y);
    for (i = 0; i < ylen; i++)
       if ( (y[i] >= 'a' && y[i] <= 'z') || (y[i] >= 'A' && y[i] <= 'Z') )
          return "Illegal character in y value.";
@@ -1206,15 +1206,19 @@ void GSF_update()
 {
    // update viewport, status bar, and possibly other bars
    inscript = false;
+   
    mainptr->UpdatePatternAndStatus();
+   
    if (showtitle) {
       mainptr->SetWindowTitle(wxEmptyString);
       showtitle = false;
    }
+   
    if (updateedit) {
       UpdateEditBar(mainptr->IsActive());
       updateedit = false;
    }
+   
    inscript = true;
 }
 
