@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -1220,15 +1220,14 @@ void Selection::ClearOutside()
 
 void Selection::AddEOL(char* &chptr)
 {
-   #if defined(__WXMAC__)
-      *chptr = '\r';      // nicer for stupid apps like LifeLab :)
-      chptr += 1;
-   #elif defined(__WXMSW__)
+   #ifdef __WXMSW__
+      // use DOS line ending (CR+LF) on Windows
       *chptr = '\r';
       chptr += 1;
       *chptr = '\n';
       chptr += 1;
-   #else // assume Unix
+   #else
+      // use LF on Linux or Mac
       *chptr = '\n';
       chptr += 1;
    #endif
@@ -1254,7 +1253,7 @@ void Selection::AddRun(int state,                // in: state of cell to write
    
    if ( run > 1 ) {
       sprintf(numstr, "%u", run);
-      numlen = strlen(numstr);
+      numlen = (unsigned int)strlen(numstr);
    } else {
       numlen = 0;                      // no run count shown if 1
    }
