@@ -1,7 +1,7 @@
                         /*** /
 
 This file is part of Golly, a Game of Life Simulator.
-Copyright (C) 2011 Andrew Trevorrow and Tomas Rokicki.
+Copyright (C) 2012 Andrew Trevorrow and Tomas Rokicki.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -226,7 +226,7 @@ wxString StatusBar::Stringify(const bigint& b)
          *p++ = '-';
       }
       sprintf(p, "%.f", d);
-      int len = strlen(p);
+      int len = (int)strlen(p);
       int commas = ((len + 2) / 3) - 1;
       int dest = len + commas;
       int src = len;
